[][src]Struct samp::prelude::UnsizedBuffer

pub struct UnsizedBuffer<'amx> { /* fields omitted */ }

It's more like a temorary buffer that comes from AMX when a native is calling.

Example

use samp_sdk::cell::UnsizedBuffer;

fn null_my_array(amx: &Amx, array: UnsizedBuffer, length: usize) -> AmxResult<u32> {
    let mut array = array.into_sized_buffer(length);

    unsafe {
        let slice = array.as_mut_slice();
        std::ptr::write_bytes(slice.as_mut_ptr(), 0, length);
    }

    return Ok(1)
}

Methods

impl<'amx> UnsizedBuffer<'amx>[src]

pub fn into_sized_buffer(self, len: usize) -> Buffer<'amx>[src]

Convert UnsizedBuffer into Buffer with given length.

Example

use samp_sdk::cell::UnsizedBuffer;

fn push_ones(amx: &Amx, array: UnsizedBuffer, length: usize) {
    let mut buffer = array.into_sized_buffer(length);
    let slice = buffer.as_mut_slice();
     
    for item in slice.iter_mut() {
        *item = 1;
    }
}

pub fn as_ptr(&self) -> *const i32[src]

Return a raw pointer to an inner value.

pub fn as_mut_ptr(&mut self) -> *mut i32[src]

Return a mutable raw pointer to an inner value.